NsAvidmGf2Share

Struct NsAvidmGf2Share 

pub struct NsAvidmGf2Share(pub(crate) Vec<AvidmGf2Share>);
Namespaced share for each storage node, contains one AvidmGf2Share for each namespace.

Tuple Fields

0: Vec<AvidmGf2Share>

Implementations

Source

impl NsAvidmGf2Share

pub fn num_nss(&self) -> usize

Return the number of namespaces in this share

pub fn weight(&self) -> usize

Return the weight of this share

pub fn validate(&self) -> bool

Validate the share structure

pub fn contains_ns(&self, ns_index: usize) -> bool

Check whether this share contains a given namespace

pub fn inner_ns_share(&self, ns_index: usize) -> Option<AvidmGf2Share>

Return the inner share for a given namespace if there exists one.

pub fn range(&self) -> Option<&Range<usize>>

The shard range this share covers, identical across all namespaces. None if the share is empty or its namespaces disagree on the range.